
# Overview

This module provides tools to take control over enabled and disabled modules.
Therefore it will provide drush commands that are configurable via settings.php
configuration.

The approach in the 7.x-2.x branch is a totally different than the 6.x-1.x, as
we will (for the moment) only provide drush commands.

# What is a master module?

A master module is a module, that holds the meta-data for the drupal application
or for a part of it by defining all dependencies for the desired functionality
(like module dependencies in the module's .info file).
Modules that are not dependent to the master module are not meant to be active,
as long it is not required by another master module.

You can have only one master module that will hold all dependencies and so
represents the functionality scope for the whole application. Or you can use
multiple master modules, where one module only handles some part of the project.

For the second approach it is a common way to use Features [1] for those
modules.

# Configuration in settings.php

In your settings.php you can define some keys in your $conf array that will
define the functionality of the module.

- "master_modules": an array of modules that are meant to be master modules for
  all scopes.
- "master_modules:SCOPE": an additional array of modules for the given scope
  that shall be handled as mater modules
- "master_uninstall_blacklist": modules that shall not be uninstalled
- "master_uninstall_blacklist:SCOPE": additional list of modules that shall not
  be uninstalled in the given scope.
- "master_allow_empty_scope": Set to TRUE if executing the drush commands shall
  be allowed without defining a scope. Defaults to FALSE

## Getting started

You can export the current state of the installation as initial configuration
array by using the `drush master-export` command. You can use that array as base
for changing the module list.

## Example

<?php
$conf['master_modules'] = array(
  'mymasterfeature1',
  'mymasterfeature2',
);
$conf['master_modules:local'] = array(
  'devel',
  'views_ui',
  'field_ui',
);
$conf['master_modules:live'] = array();
$conf['master_uninstall_blacklist'] = array();
$conf['master_uninstall_blacklist:live'] = array(
  'migrate',
);
$conf['master_allow_empty_scope'] = TRUE; // Defaults to FALSE.
?>

# What is scope used for?

You can specify an additional master module list for a specific scope. A common
use case is, to use different scopes for different stages, like "local",
"testing" or "live".

By calling the drush command with a --scope you are able to add additional
modules to that master module set only for this specific scope.

Example:
- drush master-ensure-modules --scope=local
- drush master-ensure-modules --scope=live

# More examples

By using `drush help` more examples are provided.

[1] http://drupal.org/project/features
